import Roact from "@rbxts/roact"
import { useEffect } from "@rbxts/roact-hooked"
import { useWorldContext } from "../contexts/worldContext"
import { ContextActionService, HttpService } from "@rbxts/services"
import Padding from "ReplicatedStorage/uiComponents/padding"

interface slotProps extends Roact.JsxInstanceProperties<Frame> {
    index: number
    keycode: Enum.KeyCode
    tool: Tool

    Event?: Roact.JsxInstanceEvents<Frame>
	Change?: Roact.JsxInstanceChangeEvents<Frame>
}

function slot(props: slotProps): Roact.Element {
    const { index, keycode, tool } = props

    const spreadableProps = { ...props } as Partial<slotProps>
    delete spreadableProps.index
    delete spreadableProps.keycode
    delete spreadableProps.tool

    const { clientState } = useWorldContext()

    const handleActivated = (): void => {
        if (tool.Parent !== clientState.character) {
            clientState.character.Humanoid.EquipTool(tool)
        } else {
            clientState.character.Humanoid.UnequipTools()
        }
    }

    // TODO: maybe opt this into our system for inputs?
    useEffect(() => {
        const guid = HttpService.GenerateGUID(false)
        ContextActionService.BindAction(
            guid,
            (_, userInputState) => {
                if (Enum.UserInputState.Begin === userInputState) handleActivated()
            },
            false,
            keycode
        )
    })

    return (
        <frame
            BackgroundColor3={Color3.fromHex("#11111b")}
            BackgroundTransparency={
                .7
            }
            Size={new UDim2(1, 0, 1, 0)}
        >
            <uiaspectratioconstraint
                AspectRatio={6}
            />
            <uicorner
                CornerRadius={new UDim(0, 8)}
            />
            <Padding
                paddingY={new UDim(.3, 0)}
            />
            <textlabel
                TextColor3={Color3.fromHex("#cdd6f4")}
                BackgroundTransparency={1}
                Size={new UDim2(.2, 0, 1, 0)}
                Font={Enum.Font.GothamBold}
                Text={tostring(index)}
                TextScaled
            />
            <textlabel
                TextColor3={Color3.fromHex("#cdd6f4")}
                BackgroundTransparency={1}
                Size={new UDim2(.8, 0, 1, 0)}
                Position={new UDim2(.2, 0, 0, 0)}
                Font={Enum.Font.Gotham}
                Text={tool.Name}
                TextXAlignment={Enum.TextXAlignment.Left}
                TextScaled
            />
        </frame>
    )
}

export default slot